ARIA: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/Region_role LANDMARKS: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles#3._landmark_roles BANNER: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/banner_role COMPLIMENTARY:

## Our partners

CONTENTINFO: RECOMMENDED:
VARIATIONS:
NAVIGATION:
REGION:
SEARCH: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/search_role